@@ -27,6 +27,14 @@
 --
 --
 -- $Log: compress_sparse.c,v $
+-- Revision 1.25  2008/08/10 15:23:24  jsedwards
+-- Added path to "Missing magic number" and "Incorrect version in header" error
+-- messages.
+--
+-- Revision 1.24  2008/07/19 15:04:13  jsedwards
+-- If 0'd out printing of every block's reference ID so it doesn't spew every
+-- block ID to the screen anymore.  Added calls to print a progress bar instead.
+--
 -- Revision 1.23  2008/04/28 12:48:55  jsedwards
 -- Added code to check for blocks where the reference ID is zero and skip over
 -- them with a warning.
@@ -229,13 +237,13 @@ int main(int argc, char* argv[])
 
     if (memcmp(&block[0], MAGIC_NUMBER, 4) != 0)
     {
-	fprintf(stderr, "Missing magic number in disk header\n");
+	fprintf(stderr, "Missing magic number in disk header: %s\n", obj_file_path);
 	exit(1);
     }
 
     if (memcmp(&block[4], VERSION_STRING, 4) != 0)
     {
-	fprintf(stderr, "Incorrect version string in disk header\n");
+	fprintf(stderr, "Incorrect version string in disk header: %s\n", obj_file_path);
 	exit(1);
     }
 
@@ -308,9 +316,13 @@ int main(int argc, char* argv[])
 
     num_blocks = 0;
 
+    nwos_start_progress_bar();
+
     // for now we can skip over public blocks because they should always stay the same
     for (chunk_num = 0; chunk_num < used_chunks; chunk_num++)
     {
+	nwos_update_progress_bar((float)num_blocks / (float)used_private_blocks);
+
 	chunk = chunk_block_offset + chunk_info[chunk_num].index * BLOCKS_IN_CHUNK;
 
 	if (lseek(obj_file_desc, chunk << 8, SEEK_SET) < 0)
@@ -369,10 +381,12 @@ int main(int argc, char* argv[])
 		}
 		else
 		{
+#if 0
+		    /* save this for verbose mode? */
 		    printf("id: %08x  block: %08x\n", ref, (uint32)chunk+i);
 		    /* printf("id: %08x\n", ref); */
 		    fflush(stdout);
-
+#endif
 		    counts[ref >> 28]++;
 
 		    if (ofp != NULL && fwrite(block, 1, sizeof(block), ofp) != sizeof(block))
@@ -390,6 +404,8 @@ int main(int argc, char* argv[])
 	}
     }
 
+    nwos_finish_progress_bar();
+
     printf("Number of blocks: %d\n", num_blocks);
 
     if (blocks_with_bad_ids > 0)
