@@ -27,6 +27,9 @@
 --
 --
 -- $Log: export_file.c,v $
+-- Revision 1.24  2008/12/27 15:00:29  jsedwards
+-- Merged from alpha_29_5_branch back into main trunk.
+--
 -- Revision 1.23.2.2  2008/12/21 14:12:52  jsedwards
 -- Changed to exit with code 1 when export_file subroutine fails.
 --
