@@ -27,6 +27,9 @@
 --
 --
 -- $Log: list_files.c,v $
+-- Revision 1.36  2008/12/27 15:00:29  jsedwards
+-- Merged from alpha_29_5_branch back into main trunk.
+--
 -- Revision 1.35.2.1  2008/12/20 16:07:59  jsedwards
 -- Fixed to report arguments that didn't match any files and return exit code
 -- of 1 if any didn't.
