@@ -27,6 +27,36 @@
 --
 --
 -- $Log: objectify.c,v $
+-- Revision 1.181  2008/10/31 13:00:57  jsedwards
+-- Moved nwos_reference_type and is_valid_private_reference functions to
+-- disk_io.c and renamed the latter to nwos_is_private_reference.
+--
+-- Revision 1.180  2008/10/28 10:28:55  jsedwards
+-- Changed so that skip_backwards parameter to set_allocation_parameters is a
+-- positive (unsigned) value.
+--
+-- Revision 1.179  2008/10/20 13:19:17  jsedwards
+-- Changed root transformations to use a simple add to the uppermost bits of
+-- the reference number instead of multiplying by a prime number.  The multiply
+-- did not distribute the numbers evenly over the entire space, the ended up
+-- being clustered together.  Also fixed nwos_create_root to randomize the
+-- transform so that the root object is not always in the same place.  This
+-- also takes care of root object references that ended up in the public or
+-- temporary space.
+--
+-- Revision 1.178  2008/10/20 11:45:13  jsedwards
+-- Added 0x00000001 to root_transform_primes (done on 2008/10/03 forgot to
+-- check in).
+--
+-- Revision 1.177  2008/10/03 12:05:58  jsedwards
+-- Change to multiply reference by one of 16 prime numbers to transform it,
+-- instead of rotating, inverting and reversing.  One problem with the
+-- rotating, inverting and reversing was that some references didn't transform
+-- well, the same values were repeated, for example: 0x55555555.
+--
+-- Revision 1.176  2008/09/30 13:28:00  jsedwards
+-- First attempt at transforming root object references.  Incomplete, do not use!
+--
 -- Revision 1.175  2008/09/01 18:22:17  jsedwards
 -- Moved most of the code from add_password.c and prep_disk.c that prepared
 -- to create the root object into nwos_create_root.  Also fixed it to read
@@ -1130,6 +1160,39 @@ static void generate_sequence_table(uint32* linear, uint32* serial, uint8 table[
 #endif
 
 
+/*********************************/
+/* Root object ID transformation */
+/*********************************/
+
+static bool is_binary_number(uint n)
+{
+    uint u;
+
+    for (u = 1; u != 0; u <<= 1)
+    {
+	if (u == n) return true;
+    }
+
+    return false;
+}
+
+
+void nwos_transform_root(ObjRef* dst_ref, ObjRef* src_ref, int num)
+{
+    int shift_count;
+
+    assert(16 <= MAX_ROOT_TRANSFORMATIONS && MAX_ROOT_TRANSFORMATIONS < 256 && is_binary_number(MAX_ROOT_TRANSFORMATIONS));
+    assert(0 <= num && num < MAX_ROOT_TRANSFORMATIONS);
+
+    shift_count = 1;
+    while ((MAX_ROOT_TRANSFORMATIONS << shift_count) != 256) shift_count++;
+
+    copy_reference(dst_ref, src_ref);
+
+    dst_ref->id[0] = src_ref->id[0] + (num << shift_count);
+}
+
+
 /**********************************/
 /* Initialization and Termination */
 /**********************************/
@@ -1169,6 +1232,8 @@ static void setup_from_big_key(uint8 big_key[16 + 8 + 4], ObjRef* root_object_re
 	while (j < i);   /* if j is less than i it means one of the tables matched and needs to be regenerated */
     }
 
+    assert(sizeof(ObjRef) == 4);   /* the following code assumes 4 byte IDs */
+
     memcpy(root_object_ref->id, big_key+20, 4);
 }
 
@@ -1178,9 +1243,11 @@ void nwos_initialize_objectify(AccessType type, const char* path)
 #ifdef PUBLIC_MODE
     assert(type == PUBLIC);
 #else
+    int i;
     int attempt;  /* number of pass phrase attempts */
     uint8 big_key[16 + 8 + 4];
     ObjRef root_object_ref;
+    ObjRef test_object_ref;
     char* incorrect_messages[] = { "Incorrect, try again.", "Wrong again, one more try.", "Sorry, no go." };
 
 #define NUM_ATTEMPTS (sizeof(incorrect_messages) / sizeof (char*))
@@ -1210,7 +1277,14 @@ void nwos_initialize_objectify(AccessType type, const char* path)
 
 	    setup_from_big_key(big_key, &root_object_ref);
 
-	    if (nwos_set_root_object(&root_object_ref)) break;   /* we have a winner! */
+	    for (i = 0; i < MAX_ROOT_TRANSFORMATIONS; i++)
+	    {
+		nwos_transform_root(&test_object_ref, &root_object_ref, i);
+
+		if (nwos_is_private_reference(&test_object_ref) && nwos_set_root_object(&test_object_ref)) break;  /* we have a winner! */
+	    }
+
+	    if (i < MAX_ROOT_TRANSFORMATIONS) break;
 	    
 	    fprintf(stderr, "%s\n", incorrect_messages[attempt]);
 	}
@@ -1252,8 +1326,11 @@ void nwos_create_root(void)
     ObjRef public_root_obj_ref;
     ObjRef private_root_obj_ref;
     ObjRef public_root_class_ref;
+    ObjRef test_object_ref;
     C_struct_Root root_obj;
     ObjRef root_class_ref;
+    int i;
+    int random_transform;
 
 
     nwos_log("nwos_create_root():");
@@ -1279,15 +1356,25 @@ void nwos_create_root(void)
 
 	nwos_get_key_from_password(big_key_1, sizeof(big_key_1));
 
-	setup_from_big_key(big_key_1, &private_root_obj_ref);
+	setup_from_big_key(big_key_1, &test_object_ref);
 
-	hash = nwos_hash_ref(&private_root_obj_ref);
+	random_transform = random() % MAX_ROOT_TRANSFORMATIONS;
 
-	if (hash != 0 && nwos_test_bit_in_map(hash))   /* that block is already used */
+	for (i = 0; i < MAX_ROOT_TRANSFORMATIONS; i++)
 	{
-	    fprintf(stderr, "\nThat pass phrase cannot be used, try a different one.\n\n");
+	    nwos_transform_root(&private_root_obj_ref, &test_object_ref, random_transform);
+
+	    if (nwos_is_private_reference(&private_root_obj_ref))
+	    {
+		hash = nwos_hash_ref(&private_root_obj_ref);
+
+		if (hash == 0 || !nwos_test_bit_in_map(hash)) break;   /* we have a winner! */
+	    }
+
+	    random_transform = (random_transform + 1) % MAX_ROOT_TRANSFORMATIONS;
 	}
-	else
+
+	if (i < MAX_ROOT_TRANSFORMATIONS)   /* found a good location */
 	{
 	    nwos_get_key_from_password(big_key_2, sizeof(big_key_2));
 
@@ -1295,6 +1382,10 @@ void nwos_create_root(void)
 
 	    fprintf(stderr, "\nKeys don't match, try again\n\n");
 	}
+	else
+	{
+	    fprintf(stderr, "\nThat pass phrase cannot be used, try a different one.\n\n");
+	}
     }
 
     /* create the private root object */
@@ -1429,17 +1520,6 @@ bool nwos_object_exists(ObjRef* ref)
 }
 
 
-Reference_Type nwos_reference_type(ObjRef* ref)
-{
-    if (nwos_ref_to_word(ref) < RESERVED_PUBLIC_BLOCKS)
-    {
-	return Public_Reference;
-    }
-
-    return Private_Reference;
-}
-
-
 #ifndef PUBLIC_MODE
 void nwos_set_security_level(Security_Level new_level)
 {
@@ -1464,15 +1544,15 @@ void nwos_set_security_level(Security_Level new_level)
 	break;
 
       case Security_Medium:
-	nwos_set_allocation_parameters( (USABLE_BLOCKS_PER_CHUNK / SECURITY_MEDIUM_N), -32, 32);
+	nwos_set_allocation_parameters( (USABLE_BLOCKS_PER_CHUNK / SECURITY_MEDIUM_N), 32, 32);
 	break;
 
       case Security_High:
-	nwos_set_allocation_parameters( (USABLE_BLOCKS_PER_CHUNK / SECURITY_HIGH_N), -128, 128);
+	nwos_set_allocation_parameters( (USABLE_BLOCKS_PER_CHUNK / SECURITY_HIGH_N), 128, 128);
 	break;
 
       case Security_Extreme:
-	nwos_set_allocation_parameters(1, -RESERVED_PRIVATE_CHUNKS, RESERVED_PRIVATE_CHUNKS);
+	nwos_set_allocation_parameters(1, RESERVED_PRIVATE_CHUNKS, RESERVED_PRIVATE_CHUNKS);
 	break;
 
       default:
