@@ -27,6 +27,13 @@
 --
 --
 -- $Log: objectify.h,v $
+-- Revision 1.154  2008/12/27 15:00:29  jsedwards
+-- Merged from alpha_29_5_branch back into main trunk.
+--
+-- Revision 1.153.2.1  2008/12/23 10:38:04  jsedwards
+-- Changed the name of the 'len' parameter to the strlcpy and strlcat functions
+-- to 'size' to be consistent with the documentation (OpenBSD man pages).
+--
 -- Revision 1.153  2008/10/31 13:03:31  jsedwards
 -- Added Unknown_Reference and Temporary_Reference types to Reference_Type,
 -- added external declarations for nwos_is_public_reference,
@@ -934,11 +941,11 @@ typedef enum { CREATED_NEW, IMPORTED_DATA, CREATED_NEW_REVISION, FOUND_EXISTING,
 
 /* These functions aren't standard */
 #ifndef HAVE_STRLCPY
-extern size_t strlcpy(char* dst, const char* src, size_t len);
+extern size_t strlcpy(char* dst, const char* src, size_t size);
 #endif
 
 #ifndef HAVE_STRLCAT
-extern size_t strlcat(char* dst, const char* src, size_t len);
+extern size_t strlcat(char* dst, const char* src, size_t size);
 #endif
 
 extern void nwos_ref_to_name(ObjRef* ref, char name[]);
