@@ -27,6 +27,15 @@
 --
 --
 -- $Log: recrypt.c,v $
+-- Revision 1.7  2008/12/27 15:00:29  jsedwards
+-- Merged from alpha_29_5_branch back into main trunk.
+--
+-- Revision 1.6.2.2  2008/12/23 11:51:23  jsedwards
+-- Fix Bug #2026708 - change to use strlcpy instead of strncpy.
+--
+-- Revision 1.6.2.1  2008/12/23 11:03:15  jsedwards
+-- Changed to use strlcpy instead of strcpy.
+--
 -- Revision 1.6  2008/09/01 00:10:54  jsedwards
 -- Fix copyright year.  NO code changes.
 --
@@ -260,7 +269,7 @@ void save_objects(ObjRef* ref_list_ref, char* class_name)
 	{
 	    assert(nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0])));
 
-	    strncpy(buffer, (char*)&header.common.version, 4);
+	    strlcpy(buffer, (char*)&header.common.version, 4);
 
 	    buffer[4] = '\0';
 	    printf("version: %s", buffer);
@@ -269,7 +278,7 @@ void save_objects(ObjRef* ref_list_ref, char* class_name)
 
 	    assert(nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0])));
 
-	    strncpy(buffer, (char*)&header.common.version, 4);
+	    strlcpy(buffer, (char*)&header.common.version, 4);
 
 	    buffer[4] = '\0';
 	    printf("version: %s", buffer);
@@ -279,7 +288,7 @@ void save_objects(ObjRef* ref_list_ref, char* class_name)
 
 	    assert(nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0])));
 
-	    strncpy(buffer, (char*)&header.common.version, 4);
+	    strlcpy(buffer, (char*)&header.common.version, 4);
 
 	    buffer[4] = '\0';
 	    printf("version: %s", buffer);
@@ -304,7 +313,7 @@ void save_objects(ObjRef* ref_list_ref, char* class_name)
 
 static void ref_to_path(ObjRef* ref, char path[OBJ_PATH_SIZE])
 {
-    strcpy(path, OBJECT_DIRECTORY);
+    assert(strlcpy(path, OBJECT_DIRECTORY, OBJECT_PATH_SIZE) < OBJECT_PATH_SIZE);
     nwos_ref_to_name(ref, &path[strlen(path)]);
 }
 
@@ -428,7 +437,7 @@ int main(int argc, char* argv[])
 	{
 	    assert(nwos_read_object_from_disk(&ref_list->references[i], &class_def_objs[i], sizeof(class_def_objs[0])));
 
-	    strncpy(buffer, (char*)&class_def_objs[i].header.common.version, 4);
+	    strlcpy(buffer, (char*)&class_def_objs[i].header.common.version, 4);
 
 	    buffer[4] = '\0';
 	    printf("version: %s", buffer);
