@@ -27,6 +27,12 @@
 --
 --
 -- $Log: security.c,v $
+-- Revision 1.22  2008/12/27 15:00:29  jsedwards
+-- Merged from alpha_29_5_branch back into main trunk.
+--
+-- Revision 1.21.2.1  2008/12/23 11:57:48  jsedwards
+-- Fix Bug #2026708 - change to use strlcpy instead of strncpy.
+--
 -- Revision 1.21  2008/09/13 15:09:27  jsedwards
 -- Fix Bug #2103915 - pass phrase now obscured in "show" mode.
 --
@@ -336,8 +342,9 @@ void nwos_get_key_from_password(uint8 key[], size_t key_size)
 
     if (test_phrase != NULL)
     {
-	strncpy(buffer, test_phrase, sizeof(buffer));  /* copy environment variable value to buffer */
-	num_chars = strlen(test_phrase);
+	num_chars = strlcpy(buffer, test_phrase, sizeof(buffer));   /* copy environment variable value to buffer */
+
+	assert(num_chars < sizeof(buffer));  
     }
     else
     {
